/*
 *  
 *  $Id: herramientacalibrado.h 4478 2011-12-13 11:55:00Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <export/iherramientacalibrado.h>

namespace GNC {

	class HerramientaCalibrado : public GNC::GCS::IHerramientaCalibrado{
	public:
		HerramientaCalibrado();
		~HerramientaCalibrado();

		//region "Realización de la interfaz IHerramienta"

		// Setup de paneles
		virtual void CrearPaneles( wxPanel* padre );

		//endregion

		//cuando hacen click en ella...
		virtual void SolicitarActivacion(const GNC::GCS::TriggerButton& buttonmask);

		virtual void ConectarContratoFalso(bool activar);
		virtual void SetVistaActiva(GNC::GCS::IVista* pVista);
		virtual void ConectarContratos(bool activar);


	protected:
	};
}
